==> openflowplugin-extension-nicira-0.7.3-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/openflowplugin/extension/nicira/action/rev140714/dst/choice/grouping/dst/choice/DstOfArpOpCaseBuilder.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.dst.choice.grouping.dst.choice;
import com.google.common.base.MoreObjects;
import com.google.common.collect.ImmutableMap;
import java.lang.Boolean;
import java.lang.Class;
import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.SuppressWarnings;
import java.util.Collections;
import java.util.HashMap;
import java.util.Map;
import java.util.Objects;
import org.opendaylight.yangtools.concepts.Builder;
import org.opendaylight.yangtools.yang.binding.Augmentation;
import org.opendaylight.yangtools.yang.binding.AugmentationHolder;
import org.opendaylight.yangtools.yang.binding.CodeHelpers;
import org.opendaylight.yangtools.yang.binding.DataObject;

/**
 * Class that builds {@link DstOfArpOpCaseBuilder} instances.
 *
 * @see DstOfArpOpCaseBuilder
 *
 */
public class DstOfArpOpCaseBuilder implements Builder<DstOfArpOpCase> {

    private Boolean _ofArpOp;


    Map<Class<? extends Augmentation<DstOfArpOpCase>>, Augmentation<DstOfArpOpCase>> augmentation = Collections.emptyMap();

    public DstOfArpOpCaseBuilder() {
    }
    public DstOfArpOpCaseBuilder(org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxmOfArpOpGrouping arg) {
        this._ofArpOp = arg.isOfArpOp();
    }

    public DstOfArpOpCaseBuilder(DstOfArpOpCase base) {
        this._ofArpOp = base.isOfArpOp();
        if (base instanceof DstOfArpOpCaseImpl) {
            DstOfArpOpCaseImpl impl = (DstOfArpOpCaseImpl) base;
            if (!impl.augmentation.isEmpty()) {
                this.augmentation = new HashMap<>(impl.augmentation);
            }
        } else if (base instanceof AugmentationHolder) {
            @SuppressWarnings("unchecked")
            Map<Class<? extends Augmentation<DstOfArpOpCase>>, Augmentation<DstOfArpOpCase>> aug =((AugmentationHolder<DstOfArpOpCase>) base).augmentations();
            if (!aug.isEmpty()) {
                this.augmentation = new HashMap<>(aug);
            }
        }
    }

    /**
     * Set fields from given grouping argument. Valid argument is instance of one of following types:
     * <ul>
     * <li>org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxmOfArpOpGrouping</li>
     * </ul>
     *
     * @param arg grouping object
     * @throws IllegalArgumentException if given argument is none of valid types
    */
    public void fieldsFrom(DataObject arg) {
        boolean isValidArg = false;
        if (arg instanceof org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxmOfArpOpGrouping) {
            this._ofArpOp = ((org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxmOfArpOpGrouping)arg).isOfArpOp();
            isValidArg = true;
        }
        CodeHelpers.validValue(isValidArg, arg, "[org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxmOfArpOpGrouping]");
    }

    public Boolean isOfArpOp() {
        return _ofArpOp;
    }
    
    @SuppressWarnings({ "unchecked", "checkstyle:methodTypeParameterName"})
    public <E$$ extends Augmentation<DstOfArpOpCase>> E$$ augmentation(Class<E$$> augmentationType) {
        return (E$$) augmentation.get(CodeHelpers.nonNullValue(augmentationType, "augmentationType"));
    }

    
    public DstOfArpOpCaseBuilder setOfArpOp(final Boolean value) {
        this._ofArpOp = value;
        return this;
    }
    
    public DstOfArpOpCaseBuilder addAugmentation(Class<? extends Augmentation<DstOfArpOpCase>> augmentationType, Augmentation<DstOfArpOpCase> augmentationValue) {
        if (augmentationValue == null) {
            return removeAugmentation(augmentationType);
        }
    
        if (!(this.augmentation instanceof HashMap)) {
            this.augmentation = new HashMap<>();
        }
    
        this.augmentation.put(augmentationType, augmentationValue);
        return this;
    }
    
    public DstOfArpOpCaseBuilder removeAugmentation(Class<? extends Augmentation<DstOfArpOpCase>> augmentationType) {
        if (this.augmentation instanceof HashMap) {
            this.augmentation.remove(augmentationType);
        }
        return this;
    }

    @Override
    public DstOfArpOpCase build() {
        return new DstOfArpOpCaseImpl(this);
    }

    private static final class DstOfArpOpCaseImpl implements DstOfArpOpCase {
    
        private final Boolean _ofArpOp;
    
        private Map<Class<? extends Augmentation<DstOfArpOpCase>>, Augmentation<DstOfArpOpCase>> augmentation = Collections.emptyMap();
    
        DstOfArpOpCaseImpl(DstOfArpOpCaseBuilder base) {
            this._ofArpOp = base.isOfArpOp();
            this.augmentation = ImmutableMap.copyOf(base.augmentation);
        }
    
        @Override
        public Class<DstOfArpOpCase> getImplementedInterface() {
            return DstOfArpOpCase.class;
        }
    
        @Override
        public Boolean isOfArpOp() {
            return _ofArpOp;
        }
        
        @SuppressWarnings({ "unchecked", "checkstyle:methodTypeParameterName"})
        @Override
        public <E$$ extends Augmentation<DstOfArpOpCase>> E$$ augmentation(Class<E$$> augmentationType) {
            return (E$$) augmentation.get(CodeHelpers.nonNullValue(augmentationType, "augmentationType"));
        }
    
        private int hash = 0;
        private volatile boolean hashValid = false;
        
        @Override
        public int hashCode() {
            if (hashValid) {
                return hash;
            }
        
            final int prime = 31;
            int result = 1;
            result = prime * result + Objects.hashCode(_ofArpOp);
            result = prime * result + Objects.hashCode(augmentation);
        
            hash = result;
            hashValid = true;
            return result;
        }
    
        @Override
        public boolean equals(Object obj) {
            if (this == obj) {
                return true;
            }
            if (!(obj instanceof DataObject)) {
                return false;
            }
            if (!DstOfArpOpCase.class.equals(((DataObject)obj).getImplementedInterface())) {
                return false;
            }
            DstOfArpOpCase other = (DstOfArpOpCase)obj;
            if (!Objects.equals(_ofArpOp, other.isOfArpOp())) {
                return false;
            }
            if (getClass() == obj.getClass()) {
                // Simple case: we are comparing against self
                DstOfArpOpCaseImpl otherImpl = (DstOfArpOpCaseImpl) obj;
                if (!Objects.equals(augmentation, otherImpl.augmentation)) {
                    return false;
                }
            } else {
                // Hard case: compare our augments with presence there...
                for (Map.Entry<Class<? extends Augmentation<DstOfArpOpCase>>, Augmentation<DstOfArpOpCase>> e : augmentation.entrySet()) {
                    if (!e.getValue().equals(other.augmentation(e.getKey()))) {
                        return false;
                    }
                }
                // .. and give the other one the chance to do the same
                if (!obj.equals(this)) {
                    return false;
                }
            }
            return true;
        }
    
        @Override
        public String toString() {
            final MoreObjects.ToStringHelper helper = MoreObjects.toStringHelper("DstOfArpOpCase");
            CodeHelpers.appendValue(helper, "_ofArpOp", _ofArpOp);
            CodeHelpers.appendValue(helper, "augmentation", augmentation.values());
            return helper.toString();
        }
    }
}

==> openflowplugin-extension-nicira-0.8.0-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/openflowplugin/extension/nicira/action/rev140714/dst/choice/grouping/dst/choice/DstOfArpOpCaseBuilder.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.dst.choice.grouping.dst.choice;
import com.google.common.base.MoreObjects;
import com.google.common.collect.ImmutableMap;
import java.lang.Boolean;
import java.lang.Class;
import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.util.Collections;
import java.util.HashMap;
import java.util.Map;
import java.util.Objects;
import org.opendaylight.yangtools.concepts.Builder;
import org.opendaylight.yangtools.yang.binding.Augmentation;
import org.opendaylight.yangtools.yang.binding.AugmentationHolder;
import org.opendaylight.yangtools.yang.binding.CodeHelpers;
import org.opendaylight.yangtools.yang.binding.DataObject;

/**
 * Class that builds {@link DstOfArpOpCaseBuilder} instances.
 *
 * @see DstOfArpOpCaseBuilder
 *
 */
public class DstOfArpOpCaseBuilder implements Builder<DstOfArpOpCase> {

    private Boolean _ofArpOp;


    Map<Class<? extends Augmentation<DstOfArpOpCase>>, Augmentation<DstOfArpOpCase>> augmentation = Collections.emptyMap();

    public DstOfArpOpCaseBuilder() {
    }
    public DstOfArpOpCaseBuilder(org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxmOfArpOpGrouping arg) {
        this._ofArpOp = arg.isOfArpOp();
    }

    public DstOfArpOpCaseBuilder(DstOfArpOpCase base) {
        this._ofArpOp = base.isOfArpOp();
        if (base instanceof DstOfArpOpCaseImpl) {
            DstOfArpOpCaseImpl impl = (DstOfArpOpCaseImpl) base;
            if (!impl.augmentation.isEmpty()) {
                this.augmentation = new HashMap<>(impl.augmentation);
            }
        } else if (base instanceof AugmentationHolder) {
            @SuppressWarnings("unchecked")
            Map<Class<? extends Augmentation<DstOfArpOpCase>>, Augmentation<DstOfArpOpCase>> aug =((AugmentationHolder<DstOfArpOpCase>) base).augmentations();
            if (!aug.isEmpty()) {
                this.augmentation = new HashMap<>(aug);
            }
        }
    }

    /**
     * Set fields from given grouping argument. Valid argument is instance of one of following types:
     * <ul>
     * <li>org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxmOfArpOpGrouping</li>
     * </ul>
     *
     * @param arg grouping object
     * @throws IllegalArgumentException if given argument is none of valid types
    */
    public void fieldsFrom(DataObject arg) {
        boolean isValidArg = false;
        if (arg instanceof org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxmOfArpOpGrouping) {
            this._ofArpOp = ((org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxmOfArpOpGrouping)arg).isOfArpOp();
            isValidArg = true;
        }
        CodeHelpers.validValue(isValidArg, arg, "[org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxmOfArpOpGrouping]");
    }

    public Boolean isOfArpOp() {
        return _ofArpOp;
    }
    
    @SuppressWarnings("unchecked")
    public <E extends Augmentation<DstOfArpOpCase>> E augmentation(Class<E> augmentationType) {
        return (E) augmentation.get(CodeHelpers.nonNullValue(augmentationType, "augmentationType"));
    }

    
    public DstOfArpOpCaseBuilder setOfArpOp(final Boolean value) {
        this._ofArpOp = value;
        return this;
    }
    
    public DstOfArpOpCaseBuilder addAugmentation(Class<? extends Augmentation<DstOfArpOpCase>> augmentationType, Augmentation<DstOfArpOpCase> augmentationValue) {
        if (augmentationValue == null) {
            return removeAugmentation(augmentationType);
        }
    
        if (!(this.augmentation instanceof HashMap)) {
            this.augmentation = new HashMap<>();
        }
    
        this.augmentation.put(augmentationType, augmentationValue);
        return this;
    }
    
    public DstOfArpOpCaseBuilder removeAugmentation(Class<? extends Augmentation<DstOfArpOpCase>> augmentationType) {
        if (this.augmentation instanceof HashMap) {
            this.augmentation.remove(augmentationType);
        }
        return this;
    }

    @Override
    public DstOfArpOpCase build() {
        return new DstOfArpOpCaseImpl(this);
    }

    private static final class DstOfArpOpCaseImpl implements DstOfArpOpCase {
    
        private final Boolean _ofArpOp;
    
        private Map<Class<? extends Augmentation<DstOfArpOpCase>>, Augmentation<DstOfArpOpCase>> augmentation = Collections.emptyMap();
    
        DstOfArpOpCaseImpl(DstOfArpOpCaseBuilder base) {
            this._ofArpOp = base.isOfArpOp();
            this.augmentation = ImmutableMap.copyOf(base.augmentation);
        }
    
        @Override
        public Class<DstOfArpOpCase> getImplementedInterface() {
            return DstOfArpOpCase.class;
        }
    
        @Override
        public Boolean isOfArpOp() {
            return _ofArpOp;
        }
        
        @SuppressWarnings("unchecked")
        @Override
        public <E extends Augmentation<DstOfArpOpCase>> E augmentation(Class<E> augmentationType) {
            return (E) augmentation.get(CodeHelpers.nonNullValue(augmentationType, "augmentationType"));
        }
    
        private int hash = 0;
        private volatile boolean hashValid = false;
        
        @Override
        public int hashCode() {
            if (hashValid) {
                return hash;
            }
        
            final int prime = 31;
            int result = 1;
            result = prime * result + Objects.hashCode(_ofArpOp);
            result = prime * result + Objects.hashCode(augmentation);
        
            hash = result;
            hashValid = true;
            return result;
        }
    
        @Override
        public boolean equals(Object obj) {
            if (this == obj) {
                return true;
            }
            if (!(obj instanceof DataObject)) {
                return false;
            }
            if (!DstOfArpOpCase.class.equals(((DataObject)obj).getImplementedInterface())) {
                return false;
            }
            DstOfArpOpCase other = (DstOfArpOpCase)obj;
            if (!Objects.equals(_ofArpOp, other.isOfArpOp())) {
                return false;
            }
            if (getClass() == obj.getClass()) {
                // Simple case: we are comparing against self
                DstOfArpOpCaseImpl otherImpl = (DstOfArpOpCaseImpl) obj;
                if (!Objects.equals(augmentation, otherImpl.augmentation)) {
                    return false;
                }
            } else {
                // Hard case: compare our augments with presence there...
                for (Map.Entry<Class<? extends Augmentation<DstOfArpOpCase>>, Augmentation<DstOfArpOpCase>> e : augmentation.entrySet()) {
                    if (!e.getValue().equals(other.augmentation(e.getKey()))) {
                        return false;
                    }
                }
                // .. and give the other one the chance to do the same
                if (!obj.equals(this)) {
                    return false;
                }
            }
            return true;
        }
    
        @Override
        public String toString() {
            final MoreObjects.ToStringHelper helper = MoreObjects.toStringHelper("DstOfArpOpCase");
            CodeHelpers.appendValue(helper, "_ofArpOp", _ofArpOp);
            CodeHelpers.appendValue(helper, "augmentation", augmentation.values());
            return helper.toString();
        }
    }
}
